@@ -8,7 +8,6 @@ from ...league import League
 from ..espn.epl_espn_league_model import EPLESPNLeagueModel
 from ..footballdata.epl_footballdata_league_model import \
     EPLFootballDataLeagueModel
-from ..oddsportal.epl_oddsportal_league_model import EPLOddsPortalLeagueModel
 from ..premierleague.epl_premierleague_league_model import \
     EPLPremierLeagueLeagueModel
 
@@ -291,6 +290,58 @@ EPL_TEAM_IDENTITY_MAP: dict[str, str] = {
     "Birmingham": BIRMINGHAM,
     "Cheltenham": CHELTENHAM,
     "Wimbledon": WIMBLEDON,
+    # PremierLeague
+    "94": BRENTFORD,
+    "21": WEST_HAM_UNITED,
+    "7": ASTON_VILLA,
+    "6": TOTTENHAM_HOTSPUR,
+    "1": MANCHESTER_UNITED,
+    "14": LIVERPOOL,
+    "39": WOLVES,
+    "56": SUNDERLAND,
+    "8": CHELSEA,
+    "17": NOTTINGHAM_FOREST,
+    "11": EVERTON,
+    "43": MANCHESTER_CITY,
+    "3": ARSENAL,
+    "54": FULHAM,
+    "40": IPSWICH_TOWN,
+    "45": NORWICH_CITY,
+    "91": BOURNEMOUTH,
+    "31": CRYSTAL_PALACE,
+    "2": LEEDS_UNITED,
+    "90": BURNLEY,
+    "4": NEWCASTLE_UNITED,
+    "36": BRIGHTON,
+    "20": SOUTHAMPTON,
+    "13": LEICESTER_CITY,
+    "24": DERBY_COUNTY,
+    "25": MIDDLESBOROUGH,
+    "41": BIRMINGHAM,
+    "30": BOLTON_WANDERERS,
+    "49": SHEFFIELD_UNITED,
+    "57": WATFORD,
+    "80": SWANSEA,
+    "35": WEST_BROMICH_ALBION,
+    "102": LUTON_TOWN,
+    "38": HUDDERSFIELD_TOWN,
+    "97": CARDIFF_CITY,
+    "110": STOKE,
+    "88": HULL,
+    "52": QUEENS_PARK_RANGERS,
+    "111": WIGAN,
+    "108": READING,
+    "5": BLACKBURN_ROVERS,
+    "92": BLACKPOOL,
+    "47": PORTSMOUTH,
+    "33": CHARLTON_ATHLETIC,
+    "55": BRADFORD,
+    "9": COVENTRY,
+    "1736": WIMBLEDON,
+    "19": SHEFFIELD_WEDS,
+    "37": BARNSLEY,
+    "105": OLDHAM,
+    "46": SWINDON,
 }
 BOLEYN_GROUND = "304"
 STADIUM_OF_LIGHT = "194"
@@ -351,6 +402,17 @@ JJB_STADIUM = "147"
 CITY_OF_MANCHESTER_STADIUM = "1379"
 WALKERS_STADIUM = "1358"
 MAINE_ROAD = "180"
+HIGHFIELD_ROAD = "Highfield Road, Coventry"
+THE_DELL = "The Dell, Southampton"
+THE_CORAL_WINDOWS_STADIUM = "The Coral Windows Stadium, Bradford"
+HILLSBOROUGH = "Hillsborough, Sheffield"
+OAKWELL = "Oakwell, Barnsley"
+BASEBALL_GROUND = "Baseball Ground, Derby"
+ROKER_PARK = "Roker Park, Sunderland"
+BURNDEN_PARK = "Burnden Park, Bolton"
+THE_COUNTY_GROUND = "The County Ground, Swindon"
+BOUNDARY_PARK = "Boundary Park, Oldham"
+AYRESOME_PARK = "Ayresome Park, Middlesbrough"
 EPL_VENUE_IDENTITY_MAP: dict[str, str] = {
     # ESPN
     "304": BOLEYN_GROUND,
@@ -420,6 +482,89 @@ EPL_VENUE_IDENTITY_MAP: dict[str, str] = {
     "2313": BLOOMFIELD_PARK,
     "4891": KC_STADIUM,
     "200": FRATTON_PARK,
+    # PremierLeague
+    "London Stadium, London": LONDON_STADIUM,
+    "Tottenham Hotspur Stadium, London": TOTTENHAM_HOTSPUR_STADIUM,
+    "Anfield, Liverpool": ANFIELD,
+    "Stadium of Light, Sunderland": STADIUM_OF_LIGHT,
+    "The City Ground, Nottingham": THE_CITY_GROUND,
+    "Etihad Stadium, Manchester": ETIHAD_STADIUM,
+    "Craven Cottage, London": CRAVEN_COTTAGE,
+    "Selhurst Park, London": SELHURT_PARK,
+    "Turf Moor, Burnley": TURF_MOOR,
+    "American Express Stadium, Falmer": AMERICAN_EXPRESS_STADIUM,
+    "Molineux Stadium, Wolverhampton": MOLINEUX_STADIUM,
+    "St. James' Park, Newcastle": ST_JAMES_PARK,
+    "Hill Dickinson Stadium, Liverpool": HILL_DICKINSON_STADIUM,
+    "Gtech Community Stadium, Brentford": GTECH_COMMUNITY_STADIUM,
+    "Villa Park, Birmingham": VILLA_PARK,
+    "Old Trafford, Manchester": OLD_TRAFFORD,
+    "Elland Road, Leeds": ELLAND_ROAD,
+    "Stamford Bridge, London": STAMFORD_BRIDGE,
+    "Emirates Stadium, London": EMIRATES_STADIUM,
+    "Vitality Stadium, Bournemouth": VITALITY_STADIUM,
+    "St. Mary's Stadium, Southampton": ST_MARYS_STADIUM,
+    "Portman Road, Ipswich": PORTMAN_ROAD,
+    "King Power Stadium, Leicester": KING_POWER_STADIUM,
+    "Goodison Park, Liverpool": GOODISON_PARK,
+    "Bramall Lane, Sheffield": BRAMALL_LANE,
+    "Kenilworth Road, Luton": KENILWORTH_ROAD,
+    "Carrow Road, Norwich": CARROW_ROAD,
+    "Vicarage Road, Watford": VICARAGE_ROAD,
+    "The Hawthorns, West Bromwich": THE_HAWTHORNS,
+    "Accu Stadium, Huddersfield": ACCU_STADIUM,
+    "Cardiff City Stadium, Cardiff": CARDIFF_CITY_STADIUM,
+    "Wembley Stadium, London": WEMBLEY_STADIUM,
+    "Liberty Stadium, Swansea": SWANSEA_COM_STADIUM,
+    "John Smith's Stadium, Huddersfield": ACCU_STADIUM,
+    "bet365 Stadium, Stoke": BET_365_STADIUM,
+    "Amex Stadium, Falmer": AMERICAN_EXPRESS_STADIUM,
+    "Swansea.com Stadium, Swansea": SWANSEA_COM_STADIUM,
+    "The MKM Stadium, Hull": MKM_STADIUM,
+    "White Hart Lane, London": WHITE_HART_LANE,
+    "Riverside Stadium, Middlesbrough": THE_RIVERSIDE_STADIUM,
+    "Boleyn Ground, London": BOLEYN_GROUND,
+    "MATRADE Loftus Road, London": LOFTUS_ROAD_STADIUM,
+    "DW Stadium, Wigan": BRICK_COMMUNITY_STADIUM,
+    "Select Car Leasing Stadium, Reading": SELECT_CAR_LEASING_STADIUM,
+    "Kiyan Prince Foundation Stadium, London": LOFTUS_ROAD_STADIUM,
+    "University of Bolton Stadium, Bolton": TOUGHSHEET_COMMUNITY_STADIUM,
+    "Ewood Park, Blackburn": EWOOD_PARK,
+    "Macron Stadium, Bolton": TOUGHSHEET_COMMUNITY_STADIUM,
+    "St. Andrew's Stadium, Birmingham": ST_ANDREWS_STADIUM,
+    "Bloomfield Road, Blackpool": BLOOMFIELD_PARK,
+    "The KC Stadium, Hull": KC_STADIUM,
+    "Britannia Stadium, Stoke": BET_365_STADIUM,
+    "Fratton Park, Portsmouth": FRATTON_PARK,
+    "KCOM Stadium, Hull": KC_STADIUM,
+    "Pride Park Stadium, Derby": PRIDE_PARK_STADIUM,
+    "St. Andrew's Trillion Trophy Stadium, Birmingham": ST_ANDREWS_STADIUM,
+    "Madejski Stadium, Reading": SELECT_CAR_LEASING_STADIUM,
+    "The Valley, London": THE_VALLEY,
+    "Highbury, London": HIGHBURY,
+    "Reebok Stadium, Bolton": TOUGHSHEET_COMMUNITY_STADIUM,
+    "Molineux, Wolverhampton": MOLINEUX_STADIUM,
+    "The Friends Provident St Mary's Stadium, Southampton": ST_MARYS_STADIUM,
+    "Sports Direct Arena, Newcastle": ST_JAMES_PARK,
+    "Loftus Road, London": LOFTUS_ROAD_STADIUM,
+    "The Riverside Stadium, Middlesbrough": THE_RIVERSIDE_STADIUM,
+    "St Andrews, Birmingham": ST_ANDREWS_STADIUM,
+    "Maine Road, Manchester": MAINE_ROAD,
+    "Loftus Road Stadium, London": LOFTUS_ROAD_STADIUM,
+    "Filbert Street, Leicester": FILBERT_STREET,
+    "iPro Stadium, Derby": PRIDE_PARK_STADIUM,
+    "Highfield Road, Coventry": HIGHFIELD_ROAD,
+    "The Dell, Southampton": THE_DELL,
+    "The Coral Windows Stadium, Bradford": THE_CORAL_WINDOWS_STADIUM,
+    "Hillsborough, Sheffield": HILLSBOROUGH,
+    "City Ground, Nottingham": THE_CITY_GROUND,
+    "Oakwell, Barnsley": OAKWELL,
+    "Baseball Ground, Derby": BASEBALL_GROUND,
+    "Roker Park, Sunderland": ROKER_PARK,
+    "Burnden Park, Bolton": BURNDEN_PARK,
+    "The County Ground, Swindon": THE_COUNTY_GROUND,
+    "Boundary Park, Oldham": BOUNDARY_PARK,
+    "Ayresome Park, Middlesbrough": AYRESOME_PARK,
 }
 EPL_PLAYER_IDENTITY_MAP: dict[str, str] = {}
 
@@ -433,9 +578,9 @@ class EPLCombinedLeagueModel(CombinedLeagueModel):
             League.EPL,
             [
                 EPLESPNLeagueModel(session, position=0),
-                EPLOddsPortalLeagueModel(session, position=1),
-                EPLFootballDataLeagueModel(session, position=2),
-                EPLPremierLeagueLeagueModel(session, position=3),
+                # EPLOddsPortalLeagueModel(session, position=1),
+                EPLFootballDataLeagueModel(session, position=1),
+                EPLPremierLeagueLeagueModel(session, position=2),
                 # EPLSportsDBLeagueModel(session, position=3),
                 # EPLSportsReferenceLeagueModel(session, position=4),
             ],
