@@ -23,4 +23,6 @@ class EPLESPNLeagueModel(ESPNLeagueModel):
 
     @classmethod
     def position_validator(cls) -> dict[str, str]:
-        return {str(x): str(x) for x in Position}
+        positions = {str(x): str(x) for x in Position}
+        positions["RCF"] = str(Position.CENTRE_FORWARD_RIGHT)
+        return positions
