@@ -24,7 +24,7 @@ def create_epl_premierleague_team_model(
         location=None,
         players=[],
         odds=[],
-        points=team["score"],
+        points=team.get("score"),
         ladder_rank=None,
         kicks=None,
         news=create_google_news_models(team_name, session, dt, League.EPL),
@@ -155,7 +155,7 @@ def create_epl_premierleague_team_model(
         minutes=None,
         own_goals=None,
         pass_percentage=None,
-        red_cards=team["redCards"],
+        red_cards=team.get("redCards"),
         starts=None,
         sub_ins=None,
         pitch_count=None,
