@@ -10,10 +10,12 @@ class League(StrEnum):
     AFL = "afl"
     AFLW = "aflw"
     ATP = "atp"
+    BUNDESLIGA = "bundesliga"
     EPL = "epl"
     FIFA = "fifa"
     HKJC = "hkjc"
     IPL = "ipl"
+    LALIGA = "laliga"
     MLB = "mlb"
     NBA = "nba"
     NCAAB = "ncaab"
@@ -34,6 +36,8 @@ def long_name(league: League) -> str:
             return "Australia Football League Womens"
         case League.ATP:
             return "Association of Tennis Professionals"
+        case League.BUNDESLIGA:
+            return "Bundesliga"
         case League.EPL:
             return "English Premier League"
         case League.FIFA:
@@ -42,6 +46,8 @@ def long_name(league: League) -> str:
             return "Hong Kong Jockey Club"
         case League.IPL:
             return "Indian Premier League"
+        case League.LALIGA:
+            return "La Liga"
         case League.MLB:
             return "Major League Basketball"
         case League.NBA:
@@ -72,6 +78,8 @@ def league_from_str(league_str: str) -> League:
             return League.AFLW
         case str(League.ATP):
             return League.ATP
+        case str(League.BUNDESLIGA):
+            return League.BUNDESLIGA
         case str(League.EPL):
             return League.EPL
         case str(League.FIFA):
@@ -80,6 +88,8 @@ def league_from_str(league_str: str) -> League:
             return League.HKJC
         case str(League.IPL):
             return League.IPL
+        case str(League.LALIGA):
+            return League.LALIGA
         case str(League.MLB):
             return League.MLB
         case str(League.NBA):
