@@ -9,7 +9,6 @@ from ..espn.nba_espn_league_model import NBAESPNLeagueModel
 from ..nba.nba_nba_league_model import NBANBALeagueModel
 from ..nbacom.nba_nbacom_league_model import NBANBAComLeagueModel
 from ..oddsportal.nba_oddsportal_league_model import NBAOddsPortalLeagueModel
-from ..sportsdb.nba_sportsdb_league_model import NBASportsDBLeagueModel
 
 ORLANDO_MAGIC = "1610612753"
 ATLANTA_HAWKS = "1610612737"
@@ -901,9 +900,9 @@ class NBACombinedLeagueModel(CombinedLeagueModel):
             [
                 NBANBALeagueModel(session, position=0),
                 NBAESPNLeagueModel(session, position=1),
-                NBASportsDBLeagueModel(session, position=2),
-                NBAOddsPortalLeagueModel(session, position=3),
-                NBANBAComLeagueModel(session, position=4),
+                NBAOddsPortalLeagueModel(session, position=2),
+                NBANBAComLeagueModel(session, position=3),
+                # NBASportsDBLeagueModel(session, position=4),
                 # NBASportsReferenceLeagueModel(session, position=5),
             ],
             league_filter,
