@@ -119,12 +119,16 @@ class OddsPortalLeagueModel(LeagueModel):
                     "/".join([TENNIS, USA, "atp-cincinnati", ""]),
                     "/".join([TENNIS, USA, "atp-winston-salem", ""]),
                 ]
+            case League.BUNDESLIGA:
+                return ["/".join([FOOTBALL, "germany", "bundesliga", ""])]
             case League.EPL:
-                return ["/".join(["football", "england", "premier-league", ""])]
+                return ["/".join([FOOTBALL, "england", "premier-league", ""])]
             case League.FIFA:
                 return ["/".join([FOOTBALL, "world", "world-championship", ""])]
             case League.IPL:
                 return ["/".join(["cricket", "india", "ipl", ""])]
+            case League.LALIGA:
+                return ["/".join([FOOTBALL, "spain", "laliga", ""])]
             case League.MLB:
                 return ["/".join(["baseball", USA, "mlb", ""])]
             case League.NBA:
@@ -158,7 +162,7 @@ class OddsPortalLeagueModel(LeagueModel):
             base_url = "https://www.oddsportal.com/" + path
             with self.session.cache_disabled():
                 with self.session.wayback_disabled():
-                    self.session.delete_urls(urls=[base_url])
+                    # self.session.delete_urls(urls=[base_url])
                     response = self.session.get(base_url)
             response.raise_for_status()
             data = extruct.extract(response.text, base_url=base_url)
@@ -200,7 +204,7 @@ class OddsPortalLeagueModel(LeagueModel):
 
                 with self.session.cache_disabled():
                     with self.session.wayback_disabled():
-                        self.session.delete_urls(urls=[url])
+                        # self.session.delete_urls(urls=[url])
                         response = self.session.get(url)
                 response.raise_for_status()
 
